import glob
import os
import unittest
import os.path
import jppy

class baseTest(unittest.TestCase):
    def __init__(self, *args):
        self.env = jppy.environment.Environment()
        unittest.TestCase.__init__(self,*args)
        
    def setUp(self):
        # set up known environment
        for f in glob.glob(os.path.join(os.environ['HOME'],".jpilot","*.pc3")):
            os.unlink(f)
